import React, { useState, useEffect } from "react";
import LeftNavigationUiConfiguratorTest from "./LeftNavigationUiConfiguratorTest";
import { Form, Row, Col, Button, Table } from "react-bootstrap";
import { FaEdit, FaUserAlt, FaBan } from "react-icons/fa";
import { Link, NavLink } from "react-router-dom";
import Alert from "react-bootstrap/Alert";
import axios from "axios";
import { useLocation } from "react-router-dom";

function UpdatePlanetOrgTest(props) {
  const location = useLocation();
  const [planetOrgInfoData, setPlanetOrgInfoData] = useState({
    id: "",
    orgName: "",
    credential: "",
    env: [
      {
        id: "",
        name: "",
        vhost: [
          {
            id: "",
            envName: "",
            name: "",
            protocol: "",
            port: "",
            cname: "",
          },
        ],
      },
    ],
  });

  //load existing planet details
  useEffect(() => {
    axios
      .get(
        `https://configurator-api-m7mkmev5sq-uc.a.run.app/planet/${new URLSearchParams(
          location.search
        ).get("planetId")}/orgs/${new URLSearchParams(location.search).get(
          "orgId"
        )}`
      )
      .then((response) => {
        setPlanetOrgInfoData({
          id: response.data.id,
          orgName: response.data.orgName,
          credential: response.data.mgmtServerLocation,
          env: response.data.env.map((ed, ix) => ({
            id: ed.id,
            name: ed.name,
            vhost: ed.vhost.map((vhd, idx) => ({
              id: vhd.id,
              envName: vhd.envName,
              name: vhd.name,
              protocol: vhd.protocol,
              port: vhd.port,
              cname: vhd.cname,
            })),
          })),
        });
      });
  }, []);

  //planet org name change
  const handlePlanetOrgNameChange = (e) => {
    let temp = { ...planetOrgInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetOrgInfoData(temp);
  };

  //planet org credential change
  const handlePlanetOrgCredentialChange = (e) => {
    let temp = { ...planetOrgInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetOrgInfoData(temp);
  };

  const submit = (e) => {
    console.log(planetOrgInfoData);
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Update Planet Org Info</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/">Update Planet Org Info</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="orgName">
                          <Form.Label column sm={2}>
                            Org Name{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="orgName"
                              onChange={handlePlanetOrgNameChange}
                              value={planetOrgInfoData.orgName}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="credential">
                          <Form.Label column sm={2}>
                            Org Credential
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="credential"
                              onChange={handlePlanetOrgCredentialChange}
                              value={planetOrgInfoData.credential}
                            />
                          </Col>
                        </Form.Group>
                        <p>Environments</p>
                        {planetOrgInfoData.env.map((envData, i) => (
                          <div className="group-field-highlight-pattern-info">
                            <Form.Group as={Row} controlId="environmentName">
                              <Form.Label column sm={2}>
                                Name
                              </Form.Label>
                              <Col sm={10}>
                                <Form.Control
                                  className="w-75"
                                  name="name"
                                  plaintext
                                  readOnly
                                  defaultValue={envData.name}
                                />
                              </Col>
                              <span className="action-pad">
                                <Link
                                  to={`/update-planet-env-info?planetId=${new URLSearchParams(
                                    location.search
                                  ).get("planetId")}&orgId=${
                                    planetOrgInfoData.id
                                  }&envId=${envData.id}`}
                                >
                                  <FaEdit />
                                </Link>
                              </span>
                            </Form.Group>
                            <p>VHost</p>
                            {envData.vhost.map((vHData, idex) => (
                              <div className="group-field-highlight-org-info">
                                <Form.Group as={Row} controlId="hostEnvName">
                                  <Form.Label column sm={2}>
                                    Env Name
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      className="w-75"
                                      name="envName"
                                      plaintext
                                      readOnly
                                      defaultValue={vHData.envName}
                                    />
                                  </Col>
                                  <span className="action-pad">
                                    <Link
                                      to={`/update-planet-host-info?vhostId=${vHData.id}`}
                                    >
                                      <FaEdit />
                                    </Link>
                                  </span>
                                </Form.Group>
                                <Form.Group as={Row} controlId="hostName">
                                  <Form.Label column sm={2}>
                                    Name
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      className="w-75"
                                      name="name"
                                      plaintext
                                      readOnly
                                      defaultValue={vHData.name}
                                    />
                                  </Col>
                                </Form.Group>
                                <Form.Group as={Row} controlId="hostProtocol">
                                  <Form.Label column sm={2}>
                                    Protocol
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      className="w-75"
                                      name="protocol"
                                      plaintext
                                      readOnly
                                      defaultValue={vHData.protocol}
                                    />
                                  </Col>
                                </Form.Group>
                                <Form.Group as={Row} controlId="hostPort">
                                  <Form.Label column sm={2}>
                                    Port
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      className="w-75"
                                      name="port"
                                      plaintext
                                      readOnly
                                      defaultValue={vHData.port}
                                    />
                                  </Col>
                                </Form.Group>
                                <Form.Group as={Row} controlId="hostCName">
                                  <Form.Label column sm={2}>
                                    CName
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      className="w-75"
                                      name="cname"
                                      plaintext
                                      readOnly
                                      defaultValue={vHData.cname}
                                    />
                                  </Col>
                                </Form.Group>
                              </div>
                            ))}
                          </div>
                        ))}
                      </Form>

                      <br />
                      <br />
                      <Button variant="primary" onClick={submit}>
                        Update
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UpdatePlanetOrgTest;
