import React, { useState, useEffect } from "react";
import LeftNavigationUiConfiguratorTest from "./LeftNavigationUiConfiguratorTest";
import { Form, Row, Col, Button, Table } from "react-bootstrap";
import { FaEdit, FaUserAlt, FaBan } from "react-icons/fa";
import { Link, NavLink } from "react-router-dom";
import Alert from "react-bootstrap/Alert";
import axios from "axios";
import { useLocation } from "react-router-dom";

function UpdatePlanetTest(props) {
  const location = useLocation();
  const [planetInfoData, setPlanetInfoData] = useState({
    planetId: "",
    planetDesc: "",
    mgmtServerLocation: "",
    credential: "",
    orgs: [
      {
        id: "",
        orgName: "",
        credential: "",
        env: [
          {
            id: "",
            name: "",
            vhost: [
              {
                id: "",
                envName: "",
                name: "",
                protocol: "",
                port: "",
                cname: "",
              },
            ],
          },
        ],
      },
    ],
  });

  //load existing planet details
  useEffect(() => {
    axios
      .get(
        `https://configurator-api-m7mkmev5sq-uc.a.run.app/planet/${new URLSearchParams(
          location.search
        ).get("planetId")}`
      )
      .then((response) => {
        setPlanetInfoData({
          planetId: response.data.planetId,
          planetDesc: response.data.planetDesc,
          mgmtServerLocation: response.data.mgmtServerLocation,
          credential: response.data.credential,
          orgs: response.data.orgs.map((od, idx) => ({
            id: od.id,
            orgName: od.orgName,
            credential: od.credential,
            env: od.env.map((envd, indx) => ({
              id: envd.id,
              name: envd.name,
              vhost: envd.vhost.map((vd, ixd) => ({
                id: vd.id,
                envName: vd.envName,
                name: vd.name,
                protocol: vd.protocol,
                port: vd.port,
                cname: vd.cname,
              })),
            })),
          })),
        });
      });
  }, []);

  //planet description change
  const handlePlanetDescriptionChange = (e) => {
    let temp = { ...planetInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetInfoData(temp);
  };

  //planet management server location change
  const handleMgmtServerLocationChange = (e) => {
    let temp = { ...planetInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetInfoData(temp);
  };

  //planet credential change
  const handleCredentialChange = (e) => {
    let temp = { ...planetInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetInfoData(temp);
  };

  const submit = (e) => {
    console.log(planetInfoData);
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Update Planet</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/">Update Planet</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="planetDesc">
                          <Form.Label column sm={2}>
                            Planet Description{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="planetDesc"
                              onChange={handlePlanetDescriptionChange}
                              value={planetInfoData.planetDesc}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="mgmtServerLocation">
                          <Form.Label column sm={2}>
                            Management Server Location
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="mgmtServerLocation"
                              onChange={handleMgmtServerLocationChange}
                              value={planetInfoData.mgmtServerLocation}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="credential">
                          <Form.Label column sm={2}>
                            Credential
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="credential"
                              onChange={handleCredentialChange}
                              value={planetInfoData.credential}
                            />
                          </Col>
                        </Form.Group>

                        <p>Orgs</p>

                        <Table className="table table-bordered table-striped data_table table">
                          <thead>
                            <tr className="text-center">
                              <th width="50%">Org Name</th>
                              <th width="50%">Operations</th>
                            </tr>
                          </thead>
                          <tbody className="data_table_scrollbar">
                            {planetInfoData.orgs.map((branch, i) => (
                              <tr key={Math.random()}>
                                <td
                                  width="50%"
                                  className="table-content"
                                  key={branch + "orgName"}
                                >
                                  {branch.orgName}
                                </td>

                                <td
                                  width="50%"
                                  className="table-content"
                                  key={branch + "operations"}
                                >
                                  <span className="action-pad">
                                    <Link
                                      to={`/update-planet-org-info?planetId=${planetInfoData.planetId}&orgId=${branch.id}`}
                                    >
                                      <FaEdit />
                                    </Link>
                                  </span>
                                </td>
                              </tr>
                            ))}
                          </tbody>
                        </Table>
                        <Link to="/onboard-planet-org">
                          <Button variant="primary">+ Add new org</Button>
                        </Link>
                      </Form>

                      <br />
                      <br />
                      <Button variant="primary" onClick={submit}>
                        Update
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UpdatePlanetTest;
